@@ -35,7 +35,8 @@ class ConsumerWorker(Thread):
             ConsumerClient(consumer_option.endpoint, consumer_option.accessKeyId, consumer_option.accessKey,
                            consumer_option.project, consumer_option.logstore, consumer_option.consumer_group_name,
                            consumer_option.consumer_name, consumer_option.securityToken,
-                           credentials_refresher=consumer_option.credentials_refresher)
+                           credentials_refresher=consumer_option.credentials_refresher,
+                           auth_version=consumer_option.auth_version, region=consumer_option.region)
         self.shut_down_flag = False
         self.logger = ConsumerWorkerLoggerAdapter(
             logging.getLogger(__name__), {"consumer_worker": self})
